@@ -1,5 +1,6 @@
 """Main CLI command for jade."""
 
+from jade.cli.run_spark_cluster import run_spark_cluster
 import logging
 
 
@@ -7,6 +8,7 @@ import click
 
 from jade.cli.run_jobs import run_jobs
 from jade.cli.run_multi_node_job import run_multi_node_job
+from jade.cli.run_spark_cluster import run_spark_cluster
 from jade.cli.run import run
 
 
@@ -21,3 +23,4 @@ def cli():
 cli.add_command(run)
 cli.add_command(run_jobs)
 cli.add_command(run_multi_node_job)
+cli.add_command(run_spark_cluster)
