@@ -1,5 +1,7 @@
 """Models for submitter options"""
 
+import re
+from datetime import timedelta
 from typing import List, Optional, Set, Union
 
 from pydantic import Field, validator
@@ -11,7 +13,7 @@ from jade.models import JadeBaseModel, HpcConfig, SingularityParams
 class SubmitterParams(JadeBaseModel):
     """Defines the submitter options selected by the user."""
 
-    generate_reports: Optional[bool] = Field(
+    generate_reports: bool = Field(
         title="generate_reports",
         description="Controls whether to generate reports after completion",
         default=True,
@@ -30,7 +32,7 @@ class SubmitterParams(JadeBaseModel):
         description="Number of processes to run in parallel on each node",
         default=None,
     )
-    per_node_batch_size: Optional[int] = Field(
+    per_node_batch_size: int = Field(
         title="per_node_batch_size",
         description="How many jobs to assign to each node",
         default=500,
@@ -45,39 +47,39 @@ class SubmitterParams(JadeBaseModel):
         description="Script to run on each node after completing jobs",
         default=None,
     )
-    poll_interval: Optional[int] = Field(
+    poll_interval: int = Field(
         title="poll_interval",
         description="Interval in seconds on which to poll jobs for status",
         default=60,
     )
-    resource_monitor_interval: Optional[int] = Field(
+    resource_monitor_interval: int = Field(
         title="resource_monitor_interval",
         description="Interval in seconds on which to collect resource stats. If None, aggregate"
         "summaries of stats.",
         default=1,
     )
-    resource_monitor_type: Optional[ResourceMonitorType] = Field(
+    resource_monitor_type: ResourceMonitorType = Field(
         title="resource_monitor_type",
         description=f"Type of resource monitoring to perform. Options: {[x.value for x in ResourceMonitorType]}",
         default=ResourceMonitorType.AGGREGATION,
     )
-    try_add_blocked_jobs: Optional[bool] = Field(
+    try_add_blocked_jobs: bool = Field(
         title="try_add_blocked_jobs",
         description="Add blocked jobs to a batch if all blocking jobs are in the batch. "
         "Be aware of time constraints.",
         default=True,
     )
-    time_based_batching: Optional[bool] = Field(
+    time_based_batching: bool = Field(
         title="time_based_batching",
         description="Use time-based batching instead of job-count-based batching",
         default=False,
     )
-    dry_run: Optional[bool] = Field(
+    dry_run: bool = Field(
         title="dry_run",
         description="Dry run mode; don't start any jobs",
         default=False,
     )
-    verbose: Optional[bool] = Field(
+    verbose: bool = Field(
         title="verbose",
         description="Enable debug logging",
         default=False,
@@ -87,8 +89,33 @@ class SubmitterParams(JadeBaseModel):
         description="Singularity container parameters",
         default=None,
     )
-    distributed_submitter: Optional[bool] = Field(
+    distributed_submitter: bool = Field(
         title="distributed_submitter",
         description="Submit new jobs and update status on compute nodes.",
         default=True,
     )
+
+    def get_wall_time(self):
+        """Return the wall time from the HPC parameters.
+
+        Returns
+        -------
+        timedelta
+
+        """
+        wall_time = getattr(self.hpc_config.hpc, "walltime", None)
+        if wall_time is None:
+            return timedelta(seconds=0xFFFFFFFF)  # largest 8-byte integer
+        return _to_timedelta(wall_time)
+
+
+_REGEX_WALL_TIME = re.compile(r"(\d+):(\d+):(\d+)")
+
+
+def _to_timedelta(wall_time):
+    match = _REGEX_WALL_TIME.search(wall_time)
+    assert match
+    hours = int(match.group(1))
+    minutes = int(match.group(2))
+    seconds = int(match.group(3))
+    return timedelta(hours=hours, minutes=minutes, seconds=seconds)
